@@ -18,6 +18,11 @@ use Params::Validate qw(validate_with :types);
 #######################
 use TMDB::Session;
 
+#######################
+# VERSION
+#######################
+our $VERSION = '1.0.1';
+
 #######################
 # PUBLIC METHODS
 #######################
@@ -53,7 +58,9 @@ sub info {
         {
             method => 'collection/' . $self->id(),
             params => {
-                language => $self->session->lang ? $self->session->lang : undef,
+                language => $self->session->lang
+                ? $self->session->lang
+                : undef,
             },
         }
     );
