@@ -29,6 +29,11 @@ use Object::Tiny qw(
 #######################
 use TMDB::Session;
 
+#######################
+# VERSION
+#######################
+our $VERSION = '1.0.1';
+
 #######################
 # PUBLIC METHODS
 #######################
@@ -56,14 +61,15 @@ sub new {
     my $self = $class->SUPER::new(%opts);
 
     my $config = $self->session->talk( { method => 'configuration' } ) || {};
-    $self->{config}              = $config;
-    $self->{img_backdrop_sizes}  = $config->{images}->{backdrop_sizes} || [];
-    $self->{img_poster_sizes}    = $config->{images}->{poster_sizes} || [];
-    $self->{img_profile_sizes}   = $config->{images}->{profile_sizes} || [];
-    $self->{img_logo_sizes}      = $config->{images}->{logo_sizes} || [];
-    $self->{img_base_url}        = $config->{images}->{base_url} || q();
-    $self->{img_secure_base_url} = $config->{images}->{secure_base_url} || q();
-    $self->{change_keys}         = $config->{change_keys} || [];
+    $self->{config}             = $config;
+    $self->{img_backdrop_sizes} = $config->{images}->{backdrop_sizes} || [];
+    $self->{img_poster_sizes}   = $config->{images}->{poster_sizes} || [];
+    $self->{img_profile_sizes}  = $config->{images}->{profile_sizes} || [];
+    $self->{img_logo_sizes}     = $config->{images}->{logo_sizes} || [];
+    $self->{img_base_url}       = $config->{images}->{base_url} || q();
+    $self->{img_secure_base_url}
+      = $config->{images}->{secure_base_url} || q();
+    $self->{change_keys} = $config->{change_keys} || [];
 
   return $self;
 } ## end sub new
